# Using the Abaqus Scripting Interface to access an output database

The following sections describe the architecture of an output database and how to use the Abaqus Scripting Interface to access data from an output database.

```{toctree}
:caption: Contents
:maxdepth: 1

python/need-what-to-understand
python/object-model
python/output-object-model
python/execute-script
python/read
python/write
python/exceptions
python/computations
python/improve-efficiency
python/examples
```
